'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = getSlots;

var _htmlparser = require('htmlparser2');

var _htmlparser2 = _interopRequireDefault(_htmlparser);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const HtmlParser = _htmlparser2.default.Parser;
const lex = require('pug-lexer');
const parse = require('pug-parser');
const wrap = require('pug-runtime/wrap');
const generateCode = require('pug-code-gen');

function getSlots(parts) {
  const output = {};
  if (parts.template && parts.template.content) {
    let template = parts.template.content;
    let lastComment = '';

    if (parts.template.attrs.lang === 'pug') {
      const funcStr = generateCode(parse(lex(parts.template.content)), {
        compileDebug: false,
        pretty: true,
        inlineRuntimeFunctions: false,
        templateName: '_parse'
      });
      const func = wrap(funcStr, '_parse');
      template = func();
    }

    const parser = new HtmlParser({
      oncomment: data => {
        if (data.search(/\@slot/) !== -1) {
          lastComment = data.replace('@slot', '').trim();
        }
      },
      ontext: text => {
        if (text.trim()) {
          lastComment = '';
        }
      },
      onopentag: (name, attrs) => {
        if (name === 'slot') {
          const nameSlot = attrs.name || 'default';
          output[nameSlot] = {
            description: lastComment
          };

          lastComment = '';
        }
      }
    });

    parser.write(template);
    parser.end();
    return output;
  }
  return {};
}