'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _parser = require('./parser');

var _parser2 = _interopRequireDefault(_parser);

var _getComponentModuleJSCode = require('./getComponentModuleJSCode');

var _getComponentModuleJSCode2 = _interopRequireDefault(_getComponentModuleJSCode);

var _getSlots = require('./getSlots');

var _getSlots2 = _interopRequireDefault(_getSlots);

var _getDocFile = require('./getDocFile');

var _getDocFile2 = _interopRequireDefault(_getDocFile);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class stateDoc {
  constructor() {
    this.file = '';
    this.docComponent = {};
    this.sourceComponent = '';
    this.docMixins = [];
    this.jscodeRequest = '';
    this.jscodeLang = undefined;
    this.docTemp = '';
    this.slots;
  }

  isMainComponent(file) {
    return file === this.file;
  }

  saveComponent(source, file) {
    if (this.isMainComponent(file) && this.sourceComponent !== source) {
      const parts = (0, _parser2.default)(source, 'name');
      this.slots = (0, _getSlots2.default)(parts);
      this.docComponent = [];
      if (parts.script) {
        this.jscodeRequest = (0, _getComponentModuleJSCode2.default)(parts, source, file);
        this.jscodeLang = parts.script.lang;
        this.docComponent = this.getDocFile(this.jscodeRequest, file, this.jscodeLang);
      }
    }
  }

  getDocFile(source, file, lang) {
    this.docTemp = (0, _getDocFile2.default)(source, file, lang);
    return this.docTemp;
  }

  isMixin(doc) {
    doc = doc || this.docTemp;
    return doc.some(docPart => {
      return docPart.kind === 'mixin';
    });
  }

  getDocJs() {
    let docMixins = [].concat.apply([], this.docMixins).filter(function (docPart) {
      return docPart.kind !== 'package';
    });
    return this.docComponent.concat(docMixins);
  }

  saveMixin(doc, file) {
    if (this.isMixin(doc)) {
      doc = doc.map(docPart => {
        let longnameSplit = docPart.longname.split('.');
        if (longnameSplit[0] === 'default') {
          longnameSplit[0] = 'module.exports';
        }
        docPart.longname = longnameSplit.join('.');
        return docPart;
      }).filter(docPart => {
        return docPart.longname !== 'module.exports';
      });
      let index;
      this.docMixins.forEach((docMixin, id) => {
        const packages = docMixin.filter(function (docPart) {
          return docPart.kind === 'package';
        })[0];
        if (packages && packages.files[0] === file) {
          index = id;
        }
      });
      if (!index) {
        this.docMixins.unshift(doc);
      }
    }
  }

  reset() {
    this.file = '';
    this.docComponent = {};
    this.sourceComponent = '';
    this.docMixins = [];
    this.jscodeRequest = '';
    this.jscodeLang = undefined;
    this.docTemp = '';
  }
}

exports.default = new stateDoc();